============================
Your development environment
============================

All code for the Yorkshire4 project is contained in `our Github repository
<https://github.com/pybee/yorkshire4>`__, so your first step is to fork
this repository, and clone a copy to your local computer.

1. Install Python 3
2. Create and active a virtual environment
3. Install sphinx:

    pip install sphinx

4. In the `docs` directory, run `make`
5. Open `docs/_build/index.hml` and check the results!

Then, work out how you can best contribute!
